@@ -19,12 +19,10 @@ from botocore.model import (
 from botocore.response import StreamingBody
 from botocore.session import Session as BotocoreSession
 
-from mypy_boto3_builder.import_helpers.import_string import ImportString
 from mypy_boto3_builder.logger import get_logger
 from mypy_boto3_builder.service_name import ServiceName, ServiceNameCatalog
 from mypy_boto3_builder.structures.argument import Argument
 from mypy_boto3_builder.structures.method import Method
-from mypy_boto3_builder.type_annotations.external_import import ExternalImport
 from mypy_boto3_builder.type_annotations.fake_annotation import FakeAnnotation
 from mypy_boto3_builder.type_annotations.internal_import import AliasInternalImport
 from mypy_boto3_builder.type_annotations.type import Type
@@ -55,14 +53,23 @@ class ShapeParser:
     """
 
     # Type map for shape types.
-    SHAPE_TYPE_MAP = {
+    SHAPE_TYPE_MAP: Mapping[str, FakeAnnotation] = {
         "integer": Type.int,
         "long": Type.int,
         "boolean": Type.bool,
         "double": Type.float,
         "float": Type.float,
-        "timestamp": ExternalImport(ImportString("datetime"), "datetime"),
+        "timestamp": TypeSubscript(Type.Union, [Type.datetime, Type.str]),
         "blob": TypeSubscript(Type.Union, [Type.bytes, Type.IOBytes, TypeClass(StreamingBody)]),
+        "blob_streaming": TypeSubscript(
+            Type.Union, [Type.bytes, Type.IOBytes, TypeClass(StreamingBody)]
+        ),
+    }
+
+    OUTPUT_SHAPE_TYPE_MAP: Mapping[str, FakeAnnotation] = {
+        "timestamp": Type.datetime,
+        "blob": Type.bytes,
+        "blob_streaming": TypeClass(StreamingBody),
     }
 
     # Alias map fixes added by botocore for documentation build.
@@ -213,7 +220,7 @@ class ShapeParser:
             if argument_type_stub is not None:
                 argument_type = argument_type_stub
             else:
-                argument_type = self._parse_shape(argument_shape, check_streaming=False)
+                argument_type = self._parse_shape(argument_shape)
             argument = Argument(argument_alias, argument_type)
             if argument_name not in required:
                 argument.default = Type.none
@@ -234,13 +241,13 @@ class ShapeParser:
             return argument_type_stub
 
         if shape:
-            return self._parse_shape(shape)
+            return self._parse_shape(shape, output=True)
 
         return Type.none
 
     @staticmethod
-    def _get_kw_flags(arguments: Sequence[Argument]) -> List[Argument]:
-        if len(arguments):
+    def _get_kw_flags(method_name: str, arguments: Sequence[Argument]) -> List[Argument]:
+        if len(arguments) and not method_name[0].isupper():
             return [Argument.kwflag()]
 
         return []
@@ -282,7 +289,7 @@ class ShapeParser:
                     operation_name,
                     operation_model.input_shape,
                 )
-                arguments.extend(self._get_kw_flags(shape_arguments))
+                arguments.extend(self._get_kw_flags(method_name, shape_arguments))
                 arguments.extend(shape_arguments)
 
             return_type = self._parse_return_type(
@@ -290,9 +297,17 @@ class ShapeParser:
             )
 
             method = Method(name=method_name, arguments=arguments, return_type=return_type)
+            if operation_model.input_shape:
+                method.request_type_annotation = method.get_request_type_annotation(
+                    self._get_typed_dict_name(operation_model.input_shape)
+                )
             result[method.name] = method
         return result
 
+    @staticmethod
+    def _get_typed_dict_name(shape: Shape, postfix: str = "") -> str:
+        return f"{shape.name}{postfix}TypeDef"
+
     def _parse_shape_string(self, shape: StringShape) -> FakeAnnotation:
         if not shape.enum:
             return Type.str
@@ -304,24 +319,29 @@ class ShapeParser:
 
         return TypeLiteral(f"{shape.name}Type", [option for option in shape.enum])
 
-    def _parse_shape_map(self, shape: MapShape) -> FakeAnnotation:
+    def _parse_shape_map(self, shape: MapShape, output_child: bool = False) -> FakeAnnotation:
         type_subscript = TypeSubscript(Type.Dict)
         if shape.key:
-            type_subscript.add_child(self._parse_shape(shape.key))
+            type_subscript.add_child(self._parse_shape(shape.key, output_child=output_child))
         else:
             type_subscript.add_child(Type.str)
         if shape.value:
-            type_subscript.add_child(self._parse_shape(shape.value))
+            type_subscript.add_child(self._parse_shape(shape.value, output_child=output_child))
         else:
             type_subscript.add_child(Type.Any)
         return type_subscript
 
-    def _parse_shape_structure(self, shape: StructureShape) -> FakeAnnotation:
+    def _parse_shape_structure(
+        self,
+        shape: StructureShape,
+        output: bool = False,
+        output_child: bool = False,
+    ) -> FakeAnnotation:
         if not shape.members.items():
             return Type.DictStrAny
 
         required = shape.required_members
-        typed_dict_name = f"{shape.name}TypeDef"
+        typed_dict_name = self._get_typed_dict_name(shape)
         shape_type_stub = get_shape_type_stub(self.service_name, typed_dict_name)
         if shape_type_stub:
             return shape_type_stub
@@ -333,10 +353,11 @@ class ShapeParser:
         for attr_name, attr_shape in shape.members.items():
             typed_dict.add_attribute(
                 attr_name,
-                self._parse_shape(attr_shape),
+                self._parse_shape(attr_shape, output_child=output or output_child),
                 attr_name in required,
             )
-        if shape.name.endswith("Output"):
+        if output:
+            typed_dict.name = self._get_typed_dict_name(shape, postfix="Response")
             for attribute in typed_dict.children:
                 attribute.required = True
             typed_dict.add_attribute(
@@ -346,34 +367,43 @@ class ShapeParser:
             )
         return typed_dict
 
-    def _parse_shape_list(self, shape: ListShape) -> FakeAnnotation:
+    def _parse_shape_list(self, shape: ListShape, output_child: bool = False) -> FakeAnnotation:
         type_subscript = TypeSubscript(Type.List)
         if shape.member:
-            type_subscript.add_child(self._parse_shape(shape.member))
+            type_subscript.add_child(self._parse_shape(shape.member, output_child=output_child))
         else:
             type_subscript.add_child(Type.Any)
         return type_subscript
 
-    def _parse_shape(self, shape: Shape, check_streaming: bool = True) -> FakeAnnotation:
-        if check_streaming and "streaming" in shape.serialization:
-            if shape.serialization["streaming"]:
-                return TypeClass(StreamingBody)
-            return Type.bytes
+    def _parse_shape(
+        self,
+        shape: Shape,
+        output: bool = False,
+        output_child: bool = False,
+    ) -> FakeAnnotation:
+        is_streaming = "streaming" in shape.serialization and shape.serialization["streaming"]
 
-        if shape.type_name in self.SHAPE_TYPE_MAP:
-            return self.SHAPE_TYPE_MAP[shape.type_name]
+        type_name = shape.type_name + ("_streaming" if is_streaming else "")
+        if output or output_child:
+            if type_name in self.OUTPUT_SHAPE_TYPE_MAP:
+                return self.OUTPUT_SHAPE_TYPE_MAP[type_name]
+
+        if type_name in self.SHAPE_TYPE_MAP:
+            return self.SHAPE_TYPE_MAP[type_name]
 
         if isinstance(shape, StringShape):
             return self._parse_shape_string(shape)
 
         if isinstance(shape, MapShape):
-            return self._parse_shape_map(shape)
+            return self._parse_shape_map(shape, output_child=output or output_child)
 
         if isinstance(shape, StructureShape):
-            return self._parse_shape_structure(shape)
+            return self._parse_shape_structure(
+                shape, output=output, output_child=output or output_child
+            )
 
         if isinstance(shape, ListShape):
-            return self._parse_shape_list(shape)
+            return self._parse_shape_list(shape, output_child=output or output_child)
 
         if self._resources_shape and shape.type_name in self._resources_shape["resources"]:
             return AliasInternalImport(shape.type_name)
@@ -414,7 +444,7 @@ class ShapeParser:
                 exclude_names=skip_argument_names,
             )
             shape_arguments.append(Argument("PaginationConfig", paginator_config_type, Type.none))
-            arguments.extend(self._get_kw_flags(shape_arguments))
+            arguments.extend(self._get_kw_flags("paginate", shape_arguments))
             arguments.extend(shape_arguments)
 
         return_type: FakeAnnotation = Type.none
@@ -450,7 +480,7 @@ class ShapeParser:
                 "Waiter", "wait", operation_name, operation_shape.input_shape
             )
             shape_arguments.append(Argument("WaiterConfig", waiter_config_type, Type.none))
-            arguments.extend(self._get_kw_flags(shape_arguments))
+            arguments.extend(self._get_kw_flags("wait", shape_arguments))
             arguments.extend(shape_arguments)
 
         return Method(name="wait", arguments=arguments, return_type=Type.none)
@@ -531,6 +561,7 @@ class ShapeParser:
             if path.endswith("[]"):
                 return_type = TypeSubscript(Type.List, [return_type])
 
+        operation_shape = None
         if "request" in action_shape:
             operation_name = action_shape["request"]["operation"]
             operation_shape = self._get_operation(operation_name)
@@ -547,13 +578,18 @@ class ShapeParser:
                     operation_shape.input_shape,
                     exclude_names=skip_argument_names,
                 )
-                arguments.extend(self._get_kw_flags(shape_arguments))
+                arguments.extend(self._get_kw_flags(method_name, shape_arguments))
                 arguments.extend(shape_arguments)
             if operation_shape.output_shape is not None and return_type is Type.none:
-                operation_return_type = self._parse_shape(operation_shape.output_shape)
+                operation_return_type = self._parse_shape(operation_shape.output_shape, output=True)
                 return_type = operation_return_type
 
-        return Method(name=method_name, arguments=arguments, return_type=return_type)
+        method = Method(name=method_name, arguments=arguments, return_type=return_type)
+        if operation_shape and operation_shape.input_shape is not None:
+            method.request_type_annotation = method.get_request_type_annotation(
+                self._get_typed_dict_name(operation_shape.input_shape, postfix=resource_name)
+            )
+        return method
 
     def get_collection_filter_method(
         self, name: str, collection: Collection, self_type: FakeAnnotation
@@ -584,7 +620,7 @@ class ShapeParser:
                 operation_model.input_shape,
                 optional_only=True,
             )
-            result.arguments.extend(self._get_kw_flags(shape_arguments))
+            result.arguments.extend(self._get_kw_flags(result.name, shape_arguments))
             result.arguments.extend(shape_arguments)
 
         return result
@@ -616,10 +652,10 @@ class ShapeParser:
                         operation_model.input_shape,
                         optional_only=True,
                     )
-                    method.arguments.extend(self._get_kw_flags(shape_arguments))
+                    method.arguments.extend(self._get_kw_flags(batch_action.name, shape_arguments))
                     method.arguments.extend(shape_arguments)
                 if operation_model.output_shape is not None:
-                    return_type = self._parse_shape(operation_model.output_shape)
+                    return_type = self._parse_shape(operation_model.output_shape, output=True)
                     method.return_type = return_type
 
         return result
