@@ -1,7 +1,7 @@
 """
 Wrapper for subscript type annotations, like `List[str]`.
 """
-from typing import Iterable, Set
+from typing import Iterable, List, Set
 
 from mypy_boto3_builder.import_helpers.import_record import ImportRecord
 from mypy_boto3_builder.type_annotations.fake_annotation import FakeAnnotation
@@ -22,8 +22,8 @@ class TypeSubscript(FakeAnnotation):
         parent: TypeAnnotation,
         children: Iterable[FakeAnnotation] = (),
     ) -> None:
-        self.parent = parent
-        self.children = list(children)
+        self.parent: TypeAnnotation = parent
+        self.children: List[FakeAnnotation] = list(children)
 
     def __hash__(self) -> int:
         return hash(f"{self.parent}.{self.children}")
